@@ -1,14 +1,3 @@
-//! This example demonstrates
-//!  - a responsive layout
-//!  - a scrollable markdown text
-//!  - a single line input field
-//!  - a password input
-//!  - a textarea
-//!  - handling key and mouse events
-//!  - managing the focus of widgets
-//!  - managing a terminal properly configured in "alternate" mode
-//!  - logging events in a file (useful for event handling debugging)
-//!
 //! run this example with
 //!   cargo run --example inputs
 //!
@@ -18,6 +7,7 @@
 #[macro_use]
 extern crate cli_log;
 
+mod clipboard;
 mod view;
 
 use {
@@ -25,11 +15,8 @@ use {
     crossterm::{
         cursor,
         event::{
-            self,
             DisableMouseCapture, EnableMouseCapture,
-            Event,
             KeyCode, KeyEvent, KeyModifiers,
-            MouseEvent, MouseEventKind, MouseButton,
         },
         terminal::{
             self,
@@ -45,7 +32,6 @@ use {
 // pub const CONTROL_C: KeyEvent = KeyEvent::new(KeyCode::Char('c'), KeyModifiers::CONTROL);
 // pub const CONTROL_Q: KeyEvent = KeyEvent::new(KeyCode::Char('q'), KeyModifiers::CONTROL);
 
-pub const CONTROL_C: KeyEvent = KeyEvent { code: KeyCode::Char('c'), modifiers: KeyModifiers::CONTROL };
 pub const CONTROL_Q: KeyEvent = KeyEvent { code: KeyCode::Char('q'), modifiers: KeyModifiers::CONTROL };
 
 fn main() -> anyhow::Result<()> {
@@ -73,40 +59,21 @@ fn run_in_alternate<W: Write>(w: &mut W) -> anyhow::Result<()> {
     let mut view = view::View::new(Area::full_screen());
     view.queue_on(w)?;
     w.flush()?;
-    loop {
-        // this simple application uses crossterm event source. If you need to deal
-        // with your own events or do tasks in background, you might prefer to use
-        // the termimad EventSource instead (see broot or bacon as examples).
-        let redraw = match event::read() {
-            Ok(Event::Key(key)) => {
-                debug!("key event: {:?}", key);
-                if key == CONTROL_Q || key == CONTROL_C {
-                    break; // quit
-                }
-                view.apply_key_event(key);
-                true
-            }
-            Ok(Event::Mouse(MouseEvent {
-                kind: MouseEventKind::Down(MouseButton::Left),
-                column,
-                row,
-                modifiers: KeyModifiers::NONE,
-            })) => {
-                view.apply_click_event(column, row);
-                true
-            }
-            Ok(Event::Resize(width, height)) => {
-                view.resize(Area::new(0, 0, width, height));
-                true
-            }
-            _ => {
-                false
-            }
-        };
-        if redraw {
+    info!("clipboard backend type: {}", terminal_clipboard::get_type());
+    let event_source = EventSource::new()?;
+    for timed_event in event_source.receiver() {
+        let mut quit = false;
+        debug!("event: {:?}", timed_event);
+        if timed_event.is_key(CONTROL_Q) {
+            quit = true;
+        } else if view.apply_timed_event(timed_event) {
             view.queue_on(w)?;
             w.flush()?;
         }
+        event_source.unblock(quit); // Don't forget to unblock the event source
+        if quit {
+            break;
+        }
     }
     Ok(())
 }
